import React, { useState, useEffect } from 'react'
import { useBooking } from '../components/BookingContext'

const tattooStyles = [
  'Realism',
  'Neo-Traditional',
  'Traditional American',
  'Dot-work',
  'Geometric',
  'Minimalist',
  'Fine Line',
  'Blackwork',
  'Traditional Japanese',
  'Watercolor',
  'Abstract',
  'Portrait',
  'Script/Lettering'
]

const artists = [
  'No Preference',
  'Sarah Chen',
  'Marcus Rodriguez',
  'Elena Volkov',
  'James Park',
  'Hiroshi Tanaka',
  'Alex Thompson'
]

const budgetRanges = [
  'Under $200',
  '$200 - $500',
  '$500 - $1000',
  '$1000 - $2000',
  '$2000 - $5000',
  'Over $5000'
]

function Booking() {
  const {
    formData,
    updateField,
    addReferenceImage,
    removeReferenceImage,
    submitBooking,
    isSubmitting,
    submitSuccess,
    submitError,
    resetForm
  } = useBooking()

  const [isLoaded, setIsLoaded] = useState(false)
  const [currentStep, setCurrentStep] = useState(1)
  const totalSteps = 3

  useEffect(() => {
    setIsLoaded(true)
  }, [])

  const handleSubmit = async (e) => {
    e.preventDefault()
    
    // Basic validation
    if (!formData.name || !formData.email || !formData.agreeToTerms) {
      alert('Please fill in all required fields and agree to terms.')
      return
    }

    await submitBooking(formData)
  }

  const handleFileUpload = (e) => {
    const files = Array.from(e.target.files)
    files.forEach(file => {
      if (file.type.startsWith('image/')) {
        const reader = new FileReader()
        reader.onload = (event) => {
          addReferenceImage({
            file,
            preview: event.target.result,
            name: file.name
          })
        }
        reader.readAsDataURL(file)
      }
    })
  }

  const nextStep = () => {
    if (currentStep < totalSteps) {
      setCurrentStep(currentStep + 1)
    }
  }

  const prevStep = () => {
    if (currentStep > 1) {
      setCurrentStep(currentStep - 1)
    }
  }

  if (submitSuccess) {
    return (
      <div className="pt-16 lg:pt-20 min-h-screen flex items-center justify-center">
        <div className="section-padding">
          <div className="container-max">
            <div className="max-w-2xl mx-auto text-center">
              <div className="mb-8">
                <svg className="w-20 h-20 mx-auto text-green-500 mb-4" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                  <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M9 12l2 2 4-4m6 2a9 9 0 11-18 0 9 9 0 0118 0z" />
                </svg>
                <h1 className="text-4xl font-serif font-bold mb-4">Booking Submitted!</h1>
                <p className="text-lg text-gray-600 mb-6">
                  Thank you for your consultation request. We'll review your submission and get back to you within 24-48 hours.
                </p>
                <p className="text-gray-600 mb-8">
                  A confirmation email has been sent to <strong>{formData.email}</strong>
                </p>
                <div className="space-y-4">
                  <button
                    onClick={resetForm}
                    className="btn-primary mr-4"
                  >
                    Submit Another Request
                  </button>
                  <a href="/" className="btn-secondary inline-block">
                    Return Home
                  </a>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>
    )
  }

  return (
    <div className="pt-16 lg:pt-20">
      {/* Header */}
      <section className="section-padding py-16 lg:py-24">
        <div className="container-max">
          <div className={`text-center transform transition-all duration-1000 ${
            isLoaded ? 'translate-y-0 opacity-100' : 'translate-y-8 opacity-0'
          }`}>
            <h1 className="text-4xl md:text-5xl lg:text-6xl font-serif font-bold mb-6">
              Book Your Consultation
            </h1>
            <p className="text-lg md:text-xl text-gray-600 max-w-3xl mx-auto">
              Ready to bring your vision to life? Fill out our consultation form and we'll 
              connect you with the perfect artist for your custom tattoo.
            </p>
          </div>
        </div>
      </section>

      {/* Progress Bar */}
      <section className="section-padding pb-8">
        <div className="container-max">
          <div className="max-w-3xl mx-auto">
            <div className="flex items-center justify-between mb-8">
              {[1, 2, 3].map((step) => (
                <div key={step} className="flex items-center">
                  <div className={`w-10 h-10 rounded-full flex items-center justify-center text-sm font-medium ${
                    step <= currentStep ? 'bg-black text-white' : 'bg-gray-200 text-gray-500'
                  }`}>
                    {step}
                  </div>
                  {step < totalSteps && (
                    <div className={`w-20 h-1 mx-4 ${
                      step < currentStep ? 'bg-black' : 'bg-gray-200'
                    }`} />
                  )}
                </div>
              ))}
            </div>
            <div className="text-center">
              <p className="text-sm text-gray-600">
                Step {currentStep} of {totalSteps}: 
                {currentStep === 1 && 'Personal Information'}
                {currentStep === 2 && 'Tattoo Details'}
                {currentStep === 3 && 'Preferences & Confirmation'}
              </p>
            </div>
          </div>
        </div>
      </section>

      {/* Booking Form */}
      <section className="section-padding pb-20">
        <div className="container-max">
          <div className="max-w-3xl mx-auto">
            <form onSubmit={handleSubmit} className="space-y-8">
              {/* Step 1: Personal Information */}
              {currentStep === 1 && (
                <div className="space-y-6">
                  <h2 className="text-2xl font-serif font-bold mb-6">Personal Information</h2>
                  
                  <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
                    <div>
                      <label htmlFor="name" className="block text-sm font-medium text-gray-700 mb-2">
                        Full Name *
                      </label>
                      <input
                        type="text"
                        id="name"
                        required
                        value={formData.name}
                        onChange={(e) => updateField('name', e.target.value)}
                        className="w-full px-4 py-3 border border-gray-300 rounded-lg focus:ring-2 focus:ring-accent focus:border-transparent"
                        placeholder="Your full name"
                      />
                    </div>
                    
                    <div>
                      <label htmlFor="email" className="block text-sm font-medium text-gray-700 mb-2">
                        Email Address *
                      </label>
                      <input
                        type="email"
                        id="email"
                        required
                        value={formData.email}
                        onChange={(e) => updateField('email', e.target.value)}
                        className="w-full px-4 py-3 border border-gray-300 rounded-lg focus:ring-2 focus:ring-accent focus:border-transparent"
                        placeholder="your.email@example.com"
                      />
                    </div>
                  </div>
                  
                  <div>
                    <label htmlFor="phone" className="block text-sm font-medium text-gray-700 mb-2">
                      Phone Number
                    </label>
                    <input
                      type="tel"
                      id="phone"
                      value={formData.phone}
                      onChange={(e) => updateField('phone', e.target.value)}
                      className="w-full px-4 py-3 border border-gray-300 rounded-lg focus:ring-2 focus:ring-accent focus:border-transparent"
                      placeholder="(123) 456-7890"
                    />
                  </div>
                  
                  <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
                    <div>
                      <label className="flex items-center space-x-3">
                        <input
                          type="checkbox"
                          checked={formData.isFirstTattoo}
                          onChange={(e) => updateField('isFirstTattoo', e.target.checked)}
                          className="w-4 h-4 text-accent border-gray-300 rounded focus:ring-accent"
                        />
                        <span className="text-sm text-gray-700">This is my first tattoo</span>
                      </label>
                    </div>
                    
                    <div>
                      <label className="flex items-center space-x-3">
                        <input
                          type="checkbox"
                          checked={formData.hasAllergies}
                          onChange={(e) => updateField('hasAllergies', e.target.checked)}
                          className="w-4 h-4 text-accent border-gray-300 rounded focus:ring-accent"
                        />
                        <span className="text-sm text-gray-700">I have allergies or skin sensitivities</span>
                      </label>
                    </div>
                  </div>
                  
                  {formData.hasAllergies && (
                    <div>
                      <label htmlFor="allergiesDescription" className="block text-sm font-medium text-gray-700 mb-2">
                        Please describe your allergies or sensitivities
                      </label>
                      <textarea
                        id="allergiesDescription"
                        rows={3}
                        value={formData.allergiesDescription}
                        onChange={(e) => updateField('allergiesDescription', e.target.value)}
                        className="w-full px-4 py-3 border border-gray-300 rounded-lg focus:ring-2 focus:ring-accent focus:border-transparent"
                        placeholder="Please provide details about your allergies..."
                      />
                    </div>
                  )}
                </div>
              )}

              {/* Step 2: Tattoo Details */}
              {currentStep === 2 && (
                <div className="space-y-6">
                  <h2 className="text-2xl font-serif font-bold mb-6">Tattoo Details</h2>
                  
                  <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
                    <div>
                      <label htmlFor="desiredStyle" className="block text-sm font-medium text-gray-700 mb-2">
                        Desired Style
                      </label>
                      <select
                        id="desiredStyle"
                        value={formData.desiredStyle}
                        onChange={(e) => updateField('desiredStyle', e.target.value)}
                        className="w-full px-4 py-3 border border-gray-300 rounded-lg focus:ring-2 focus:ring-accent focus:border-transparent"
                      >
                        <option value="">Select a style</option>
                        {tattooStyles.map((style) => (
                          <option key={style} value={style}>{style}</option>
                        ))}
                      </select>
                    </div>
                    
                    <div>
                      <label htmlFor="size" className="block text-sm font-medium text-gray-700 mb-2">
                        Approximate Size (cm)
                      </label>
                      <input
                        type="text"
                        id="size"
                        value={formData.size}
                        onChange={(e) => updateField('size', e.target.value)}
                        className="w-full px-4 py-3 border border-gray-300 rounded-lg focus:ring-2 focus:ring-accent focus:border-transparent"
                        placeholder="e.g., 10cm x 15cm"
                      />
                    </div>
                  </div>
                  
                  <div>
                    <label htmlFor="placement" className="block text-sm font-medium text-gray-700 mb-2">
                      Placement on Body
                    </label>
                    <input
                      type="text"
                      id="placement"
                      value={formData.placement}
                      onChange={(e) => updateField('placement', e.target.value)}
                      className="w-full px-4 py-3 border border-gray-300 rounded-lg focus:ring-2 focus:ring-accent focus:border-transparent"
                      placeholder="e.g., forearm, shoulder, back"
                    />
                  </div>
                  
                  <div>
                    <label htmlFor="description" className="block text-sm font-medium text-gray-700 mb-2">
                      Describe Your Vision
                    </label>
                    <textarea
                      id="description"
                      rows={4}
                      value={formData.description}
                      onChange={(e) => updateField('description', e.target.value)}
                      className="w-full px-4 py-3 border border-gray-300 rounded-lg focus:ring-2 focus:ring-accent focus:border-transparent"
                      placeholder="Tell us about your tattoo idea, inspiration, meaning, or any specific details..."
                    />
                  </div>
                  
                  <div>
                    <label htmlFor="budget" className="block text-sm font-medium text-gray-700 mb-2">
                      Budget Range
                    </label>
                    <select
                      id="budget"
                      value={formData.budget}
                      onChange={(e) => updateField('budget', e.target.value)}
                      className="w-full px-4 py-3 border border-gray-300 rounded-lg focus:ring-2 focus:ring-accent focus:border-transparent"
                    >
                      <option value="">Select budget range</option>
                      {budgetRanges.map((range) => (
                        <option key={range} value={range}>{range}</option>
                      ))}
                    </select>
                  </div>
                  
                  <div>
                    <label htmlFor="referenceImages" className="block text-sm font-medium text-gray-700 mb-2">
                      Reference Images
                    </label>
                    <input
                      type="file"
                      id="referenceImages"
                      multiple
                      accept="image/*"
                      onChange={handleFileUpload}
                      className="w-full px-4 py-3 border border-gray-300 rounded-lg focus:ring-2 focus:ring-accent focus:border-transparent"
                    />
                    <p className="text-xs text-gray-500 mt-1">
                      Upload reference images, inspiration, or sketches (max 5 images)
                    </p>
                    
                    {formData.referenceImages.length > 0 && (
                      <div className="mt-4 grid grid-cols-2 md:grid-cols-4 gap-4">
                        {formData.referenceImages.map((image, index) => (
                          <div key={index} className="relative">
                            <img
                              src={image.preview}
                              alt={`Reference ${index + 1}`}
                              className="w-full h-24 object-cover rounded-lg"
                            />
                            <button
                              type="button"
                              onClick={() => removeReferenceImage(index)}
                              className="absolute -top-2 -right-2 w-6 h-6 bg-red-500 text-white rounded-full flex items-center justify-center text-xs hover:bg-red-600"
                            >
                              ×
                            </button>
                          </div>
                        ))}
                      </div>
                    )}
                  </div>
                </div>
              )}

              {/* Step 3: Preferences & Confirmation */}
              {currentStep === 3 && (
                <div className="space-y-6">
                  <h2 className="text-2xl font-serif font-bold mb-6">Preferences & Confirmation</h2>
                  
                  <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
                    <div>
                      <label htmlFor="preferredArtist" className="block text-sm font-medium text-gray-700 mb-2">
                        Preferred Artist
                      </label>
                      <select
                        id="preferredArtist"
                        value={formData.preferredArtist}
                        onChange={(e) => updateField('preferredArtist', e.target.value)}
                        className="w-full px-4 py-3 border border-gray-300 rounded-lg focus:ring-2 focus:ring-accent focus:border-transparent"
                      >
                        {artists.map((artist) => (
                          <option key={artist} value={artist}>{artist}</option>
                        ))}
                      </select>
                    </div>
                    
                    <div>
                      <label htmlFor="preferredDate" className="block text-sm font-medium text-gray-700 mb-2">
                        Preferred Date
                      </label>
                      <input
                        type="date"
                        id="preferredDate"
                        value={formData.preferredDate}
                        onChange={(e) => updateField('preferredDate', e.target.value)}
                        min={new Date().toISOString().split('T')[0]}
                        className="w-full px-4 py-3 border border-gray-300 rounded-lg focus:ring-2 focus:ring-accent focus:border-transparent"
                      />
                    </div>
                  </div>
                  
                  <div className="bg-gray-50 p-6 rounded-lg">
                    <h3 className="text-lg font-serif font-semibold mb-4">Important Information</h3>
                    <ul className="space-y-2 text-sm text-gray-600">
                      <li>• Consultation fee: $50 (applied to final tattoo cost)</li>
                      <li>• Minimum age requirement: 18 years old</li>
                      <li>• Deposit required to secure appointment</li>
                      <li>• 48-hour cancellation policy</li>
                      <li>• Please arrive well-rested and hydrated</li>
                    </ul>
                  </div>
                  
                  <div className="space-y-4">
                    <label className="flex items-start space-x-3">
                      <input
                        type="checkbox"
                        required
                        checked={formData.agreeToTerms}
                        onChange={(e) => updateField('agreeToTerms', e.target.checked)}
                        className="w-4 h-4 text-accent border-gray-300 rounded focus:ring-accent mt-1"
                      />
                      <span className="text-sm text-gray-700">
                        I agree to the <a href="/terms" className="text-accent hover:underline">terms and conditions</a> and 
                        <a href="/privacy" className="text-accent hover:underline"> privacy policy</a>. 
                        I understand that a consultation fee applies and confirm I am 18+ years old. *
                      </span>
                    </label>
                  </div>
                </div>
              )}

              {/* Navigation Buttons */}
              <div className="flex justify-between pt-8">
                <button
                  type="button"
                  onClick={prevStep}
                  disabled={currentStep === 1}
                  className={`px-6 py-3 rounded-lg font-medium transition-colors duration-300 ${
                    currentStep === 1
                      ? 'bg-gray-100 text-gray-400 cursor-not-allowed'
                      : 'bg-gray-200 text-gray-700 hover:bg-gray-300'
                  }`}
                >
                  Previous
                </button>
                
                {currentStep < totalSteps ? (
                  <button
                    type="button"
                    onClick={nextStep}
                    className="btn-primary"
                  >
                    Next Step
                  </button>
                ) : (
                  <button
                    type="submit"
                    disabled={isSubmitting}
                    className="btn-primary disabled:opacity-50 disabled:cursor-not-allowed"
                  >
                    {isSubmitting ? 'Submitting...' : 'Submit Consultation Request'}
                  </button>
                )}
              </div>
              
              {submitError && (
                <div className="bg-red-50 border border-red-200 rounded-lg p-4 text-red-700">
                  <p className="font-medium">Error submitting form:</p>
                  <p className="text-sm">{submitError}</p>
                </div>
              )}
            </form>
          </div>
        </div>
      </section>
    </div>
  )
}

export default Booking